Package: plotdap
Title: Easily Visualize Data from 'ERDDAP™' Servers via the 'rerddap'
        Package
Version: 1.2.0
Date: 2026-05-04
Authors@R: c(
    person("Carson", "Sievert", role = "aut"),
    person("Roy", "Mendelssohn", role = c("aut", "ctb", "cre"), email = "roy.mendelssohn@noaa.gov"))
Description: Easily visualize and animate 'tabledap' and 'griddap' objects obtained via the 'rerddap' package in a simple one-line command,  using either base graphics or 'ggplot2' graphics. 'plotdap' handles extracting and reshaping the data,  map projections and continental outlines.  Optionally the data can be animated through time using the 'gganmiate' package.
License: MIT + file LICENSE
URL: https://github.com/rmendels/plotdap
BugReports: https://github.com/rmendels/plotdap/issues
Depends: R (>= 4.3.0)
Imports: cmocean, dplyr, gganimate, ggnewscale, ggplot2 (>= 3.1.0),
        isoband, lazyeval, lubridate, magrittr, mapdata, maps, raster,
        rerddap (>= 1.0.0), rlang, scales, sf, tidyr, viridis
Suggests: Cairo, knitr, plotly, rmarkdown, testthat
LazyData: true
Encoding: UTF-8
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-08 16:12:18 UTC; rmendels
Author: Carson Sievert [aut],
  Roy Mendelssohn [aut, ctb, cre]
Maintainer: Roy Mendelssohn <roy.mendelssohn@noaa.gov>
Repository: CRAN
Date/Publication: 2026-05-09 14:41:33 UTC
Built: R 4.5.2; ; 2026-05-09 17:09:43 UTC; unix
