# Generated by roxygen2: do not edit by hand

S3method(print,ggplotdap)
S3method(print,plotdap)
export("%>%")
export(add_ggplot)
export(add_griddap)
export(add_griddap_contours)
export(add_tabledap)
export(bbox_set)
export(plotdap)
import(mapdata)
import(rerddap)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_gradientn)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,theme_bw)
importFrom(magrittr,"%>%")
importFrom(maps,map)
importFrom(raster,brick)
importFrom(raster,calc)
importFrom(raster,crs)
importFrom(raster,extent)
importFrom(raster,isLonLat)
importFrom(raster,ncell)
importFrom(raster,ncol)
importFrom(raster,nlayers)
importFrom(raster,nrow)
importFrom(raster,plot)
importFrom(raster,projectRaster)
importFrom(raster,raster)
importFrom(raster,rasterToPolygons)
importFrom(raster,resample)
importFrom(raster,setExtent)
importFrom(raster,values)
importFrom(rlang,.data)
importFrom(scales,col_numeric)
importFrom(scales,rescale)
importFrom(sf,st_as_sf)
importFrom(sf,st_bbox)
importFrom(sf,st_crs)
importFrom(sf,st_graticule)
importFrom(sf,st_transform)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(tidyr,gather_)
importFrom(utils,getFromNamespace)
importFrom(utils,packageVersion)
