#' QMwind Data
#'
#' pre-Download of QMwind in `add_griddap()` example so that example
#' can run within CRAN Time limits
#'
#' obtained using the `rerddap` command
#' wind <- griddap('erdQMwindmday',
#'        time = c('2016-11-16', '2017-01-16'), latitude = c(30, 50),
#'        longitude = c(210, 240),
#'        fields = 'x_wind')
#' )
"QMwind"
