#' murSST Data
#'
#' pre-Download of murSST in `add_griddap()` example so that example
#' can run within CRAN Time limits
#'
#' obtained using the `rerddap` command
#' murSST <- griddap(
#' 'jplMURSST41', latitude = c(22, 51), longitude = c(-140, -105),
#' time = c('last', 'last'), fields = 'analysed_sst'
#' )
"murSST"
